package com.zhyc.module.biosafety.mapper;

import java.util.List;

import com.zhyc.module.biosafety.domain.SwMedicineUsage;
import com.zhyc.module.biosafety.domain.SwMedicineUsageDetails;
import org.apache.ibatis.annotations.Mapper;

/**
 * 药品使用记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-12
 */
@Mapper
public interface SwMedicineUsageMapper 
{
    /**
     * 查询药品使用记录
     * 
     * @param id 药品使用记录主键
     * @return 药品使用记录
     */
    public SwMedicineUsage selectSwMedicineUsageById(Integer id);

    /**
     * 查询药品使用记录列表
     * 
     * @param swMedicineUsage 药品使用记录
     * @return 药品使用记录集合
     */
    public List<SwMedicineUsage> selectSwMedicineUsageList(SwMedicineUsage swMedicineUsage);

    /**
     * 新增药品使用记录
     * 
     * @param swMedicineUsage 药品使用记录
     * @return 结果
     */
    public int insertSwMedicineUsage(SwMedicineUsage swMedicineUsage);

    /**
     * 修改药品使用记录
     * 
     * @param swMedicineUsage 药品使用记录
     * @return 结果
     */
    public int updateSwMedicineUsage(SwMedicineUsage swMedicineUsage);

    /**
     * 删除药品使用记录
     * 
     * @param id 药品使用记录主键
     * @return 结果
     */
    public int deleteSwMedicineUsageById(Integer id);

    /**
     * 批量删除药品使用记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSwMedicineUsageByIds(Long[] ids);

    /**
     * 批量删除药品使用记录详情
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSwMedicineUsageDetailsByMediUsages(Long[] ids);
    
    /**
     * 批量新增药品使用记录详情
     * 
     * @param swMedicineUsageDetailsList 药品使用记录详情列表
     * @return 结果
     */
    public int batchSwMedicineUsageDetails(List<SwMedicineUsageDetails> swMedicineUsageDetailsList);
    

    /**
     * 通过药品使用记录主键删除药品使用记录详情信息
     * 
     * @param id 药品使用记录ID
     * @return 结果
     */
    public int deleteSwMedicineUsageDetailsByMediUsage(Integer id);

    List<SwMedicineUsageDetails> selectSwMedicineUsageDetailsById(Integer id);
}
